// Copyright 2023-latest the httpland authors. All rights reserved. MIT license.
// This module is browser compatible.
import { Header } from "./deps.js";
export function withCacheControl(_, response, directives) {
    const hasCacheControl = response.headers.has(Header.CacheControl);
    if (hasCacheControl)
        return response;
    const cacheControl = stringifyCacheDirectives({ ...directives });
    if (!cacheControl)
        return response;
    response.headers.set(Header.CacheControl, cacheControl);
    return response;
}
export function stringifyCacheDirectives(record) {
    const fieldValues = Object.entries(record).map(([key, value]) => stringifyDirective(key, value));
    return fieldValues
        .filter(Boolean)
        .join(", ");
}
export function stringifyDirective(key, value) {
    if (!key)
        return "";
    if (value === true)
        return key;
    return `${key}=${value}`;
}
