"use strict";
// Copyright 2023-latest the httpland authors. All rights reserved. MIT license.
// This module is browser compatible.
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringifyDirective = exports.stringifyCacheDirectives = exports.withCacheControl = void 0;
const deps_js_1 = require("./deps.js");
function withCacheControl(_, response, directives) {
    const hasCacheControl = response.headers.has(deps_js_1.Header.CacheControl);
    if (hasCacheControl)
        return response;
    const cacheControl = stringifyCacheDirectives({ ...directives });
    if (!cacheControl)
        return response;
    response.headers.set(deps_js_1.Header.CacheControl, cacheControl);
    return response;
}
exports.withCacheControl = withCacheControl;
function stringifyCacheDirectives(record) {
    const fieldValues = Object.entries(record).map(([key, value]) => stringifyDirective(key, value));
    return fieldValues
        .filter(Boolean)
        .join(", ");
}
exports.stringifyCacheDirectives = stringifyCacheDirectives;
function stringifyDirective(key, value) {
    if (!key)
        return "";
    if (value === true)
        return key;
    return `${key}=${value}`;
}
exports.stringifyDirective = stringifyDirective;
