"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Copyright 2023-latest the httpland authors. All rights reserved. MIT license.
// This module is browser compatible.
require("./_dnt.polyfills.js");
const cache_control_js_1 = require("./cache_control.js");
const util_js_1 = require("./util.js");
/** HTTP `cache-control` header middleware factory.
 *
 * @example
 * ```ts
 * import cacheControl from "https://deno.land/x/http_cache_control@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std/testing/asserts.ts";
 *
 * const middleware = cacheControl({
 *   "max-age": 604800,
 *   immutable: true,
 *   public: true,
 * });
 * declare const request: Request;
 * const handler = () => new Response("hello");
 *
 * const response = await middleware(request, handler);
 *
 * assertEquals(
 *   response.headers.get("cache-control"),
 *   "max-age=604800, immutable, public",
 * );
 * ```
 *
 * @throws {AggregateError} If directives include invalid value.
 */
function cacheControl(directives) {
    (0, util_js_1.assertValidDirectives)(directives);
    return async (request, next) => {
        const response = await next(request);
        return (0, cache_control_js_1.withCacheControl)(request, response, directives);
    };
}
exports.default = cacheControl;
