/** Whether the value has the property or not.
 * The difference from `Object.hasOwn` is that it has a Type guard.
 * @param key Any property key.
 * @param value Any object.
 * @example
 * ```ts
 * import { hasOwn } from "https://deno.land/x/isx@$VERSION/mod.ts";
 *
 * const object: object = {};
 * if (hasOwn("", object)) {
 *   object[""]; // No type error.
 * }
 * ```
 */
export declare function hasOwn<T extends PropertyKey, U extends {}>(key: T, value: U): value is U & {
    [k in T]: unknown;
};
